@@ -1,11 +1,11 @@
 package Devel::Platform::Match;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-08'; # DATE
+our $DATE = '2020-10-09'; # DATE
 our $DIST = 'Devel-Platform-Match'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
-use 5.010001;
+use 5.014;
 use strict;
 use warnings;
 
@@ -391,7 +391,7 @@ Devel::Platform::Match - Match platform information with platform specification
 
 =head1 VERSION
 
-This document describes version 0.004 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
+This document describes version 0.005 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-09.
 
 =head1 SYNOPSIS
 
@@ -487,7 +487,7 @@ Examples:
 
 =item * Example #1:
 
- match_platform("osflag=linux", { oslabel => "Debian", osflag => "linux" });
+ match_platform("osflag=linux", { osflag => "linux", oslabel => "Debian" });
 
 Result:
 
